@@ -1,7 +1,7 @@
-def is_between_hours_utc(cls, start_h_utc: float, stop_h_utc: float) -> bool:
+def is_between_hours_utc(start_h_utc: float, stop_h_utc: float) -> bool:
     return is_between_seconds_utc(start_h_utc*3600, stop_h_utc*3600)
 
-def is_between_seconds_utc(cls, start_s_utc: float, stop_s_utc: float) -> bool:
+def is_between_seconds_utc(start_s_utc: float, stop_s_utc: float) -> bool:
         s_in_day = 60*60*24
 
         if start_s_utc >= s_in_day:
@@ -19,10 +19,10 @@ def is_between_seconds_utc(cls, start_s_utc: float, stop_s_utc: float) -> bool:
 
         return False
 
-def hours_till(cls, h_utc: float) -> float:
+def hours_till(h_utc: float) -> float:
     return seconds_till(h_utc*3600)/3600
 
-def seconds_till(cls, s_utc: float) -> float:
+def seconds_till(s_utc: float) -> float:
     now_s = cls.__current_sec_utc()
 
     if s_utc >= now_s:
